package com.cultural.heritage.controller.order;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cultural.heritage.annotation.AuthCheck;
import com.cultural.heritage.common.BaseResponse;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.common.ResultUtils;
import com.cultural.heritage.constant.UserConstant;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.model.dto.refund.RefundRecordQueryRequest;
import com.cultural.heritage.model.entity.RefundRecord;
import com.cultural.heritage.service.order.RefundRecordService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping("/refund")
@Slf4j
@Tag(name = "退款管理模块")
@Transactional(rollbackFor = Exception.class)
public class RefundRecordController {


    @Resource
    private RefundRecordService refundRecordService;


    /**
     * web端管理员分页查询退款记录
     * @param refundRecordQueryRequest  退款记录查询请求体
     * @return  退款记录列表
     */
    @PostMapping("/list")
    @Operation(summary = "web端管理员分页查询退款记录", description = "参数：地址添加请求体，权限：所有人，方法名：addAddress")
    @AuthCheck(mustRole = UserConstant.ADMIN_ROLE)
    public BaseResponse<Page<RefundRecord>> listRefundRecord(@RequestBody RefundRecordQueryRequest refundRecordQueryRequest) {
        if (refundRecordQueryRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        long current = refundRecordQueryRequest.getCurrent();
        long pageSize = refundRecordQueryRequest.getPageSize();
        QueryWrapper<RefundRecord> queryWrapper = refundRecordService.getQueryWrapper(refundRecordQueryRequest);
        Page<RefundRecord> page = refundRecordService.page(new Page<>(current, pageSize), queryWrapper);

        return ResultUtils.success(page);
    }



}
