package com.cultural.heritage.model.dto.photoProducts;

import com.cultural.heritage.model.dto.bookingDate.BookingDateAddRequest;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;


@Data
@Schema(description = "写真产品添加请求体", requiredProperties =
        {"name", "introImg", "richText", "minNumber", "maxNumber", "shotScene", "price", "categoryId"})
public class PhotoProductsAddRequest implements Serializable {



    /**
     * 产品名称
     */
    @Schema(description = "产品名称", example = "彩绣菊花纹刺绣长袍")
    private String name;


    /**
     * 介绍图片
     */
    @Schema(description = "介绍图片", example = "https://www.xxx.jpg")
    private String introImg;


    /**
     * 产品详情（富文本）
     */
    private String richText;


    /**
     * 最小预约人数
     */
    @Schema(description = "最小预约人数", example = "4")
    private Integer minNumber;


    /**
     * 最大预约人数
     */
    @Schema(description = "最大预约人数", example = "10")
    private Integer maxNumber;


    /**
     * 拍摄场景
     */
    @Schema(description = "拍摄场景", example = "室内")
    private String shotScene;



    /**
     * 产品价格
     */
    @Schema(description = "产品价格", example = "100.00")
    private BigDecimal price;


    /**
     * 写真类别名称
     */
    @Schema(description = "写真类别名称", example = "5")
    private String categoryName;



    /**
     * 未来的预约详情
     */
    @Schema(description = "未来的预约详情")
    private List<BookingDateAddRequest> bookingDateAddRequestList;


    @Serial
    private static final long serialVersionUID = 1L;
}
