package com.cultural.heritage.service.address.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.exception.ThrowUtils;
import com.cultural.heritage.mapper.AddressMapper;
import com.cultural.heritage.model.entity.Address;
import com.cultural.heritage.service.address.AddressService;
import com.cultural.heritage.utils.RegexUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.List;

@Service
public class AddressServiceImpl extends ServiceImpl<AddressMapper, Address> implements AddressService {

    @Override
    public void verifyIsDefault(Address address) {
        Integer isDefault = address.getIsDefault();
        Long userId = address.getUserId();
        List<Address> list = this.getUserAddressById(userId);
        if (CollectionUtils.isEmpty(list)) {
            return ;
        }
        if (isDefault == 1) {
            list.forEach(item -> item.setIsDefault(0));
        }
        boolean result = this.updateBatchById(list);
        ThrowUtils.throwIf(!result, ErrorCode.OPERATION_ERROR);
    }

    @Override
    public List<Address> getUserAddressById(Long userId) {
        QueryWrapper<Address> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("userId", userId);
        List<Address> list = this.list(queryWrapper);
        return list;
    }


    /**
     * 校验用户提交的地址信息
     */
    @Override
    public void validAddress(Address address, boolean update) {
        Long userId = address.getUserId();
        String name = address.getName();
        String phone = address.getPhone();
        String region = address.getRegion();
        String detailAddress = address.getDetailAddress();
        Integer isDefault = address.getIsDefault();

        if (update) {
            if (userId == null) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "参数id错误");
            }
        }
        if (ObjectUtils.isEmpty(isDefault) || isDefault != 1 && isDefault != 0) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        if (StringUtils.isAnyBlank(name, region, detailAddress, phone)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "参数不全");
        }
        if (StringUtils.isNotBlank(phone) && RegexUtils.isPhoneInvalid(phone)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "手机号格式无效");
        }
    }

}
