package com.cultural.heritage.service.file.impl;

import com.cultural.heritage.config.HweiOBSConfig;
import com.cultural.heritage.service.file.IHweiYunOBSService;
import com.obs.services.ObsClient;
import com.obs.services.exception.ObsException;
import com.obs.services.model.*;
import jakarta.annotation.Resource;
import jakarta.servlet.ServletOutputStream;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.io.InputStream;
import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;


/**
 * 华为云OBS服务业务层
 */

@Service
@Slf4j
public class HweiYunOBSServiceImpl implements IHweiYunOBSService {


	@Resource
	private HweiOBSConfig hweiOBSConfig;




	/**
	 * OBS-文件上传
	 * @param uploadFile 文件对象
	 * @param objectKey	具体的文件名（含存储路径）
	 * @return	PutObjectResult
	 */
	@Override
	public PutObjectResult fileUpload(MultipartFile uploadFile, String objectKey) {
		ObsClient obsClient = null;
		PutObjectResult putObjectResult = null;
		try {
			String bucketName = hweiOBSConfig.getBucketName();
			obsClient = hweiOBSConfig.getInstance();
			InputStream inputStream = uploadFile.getInputStream();
			long available = inputStream.available();
			PutObjectRequest putObjectRequest = new PutObjectRequest(bucketName, objectKey, inputStream);

			ObjectMetadata objectMetadata = new ObjectMetadata();
			objectMetadata.setContentLength(available);
			putObjectRequest.setMetadata(objectMetadata);
			// 设置对象访问权限为公共读
			putObjectRequest.setAcl(AccessControlList.REST_CANNED_PUBLIC_READ);
			putObjectResult  = obsClient.putObject(putObjectRequest);
			// 读取该已上传对象的URL
		} catch (ObsException | IOException e) {
			log.info("上传文件失败");
		} finally {
			hweiOBSConfig.destroy(obsClient);
		}
		return putObjectResult;
	}

	/*
	 * @Description : 文件下载
	 * @author      : YBL
	 * @date        : 2025/3/14 14:46
	 */
	@Override
	public void downloadFile(String objectKey, HttpServletResponse response) {
		// 使用永久AK/SK初始化客户端
		ObsClient obsClient = hweiOBSConfig.getInstance();
		try {
			// 清空response
			response.reset();
			// 设置response的Header
			response.setContentType("application/octet-stream");
			response.addHeader("Content-Disposition", "inline;filename=" + URLEncoder.encode(objectKey, StandardCharsets.UTF_8));
			response.setCharacterEncoding("UTF-8");
			// 流式下载
			ObsObject obsObject = obsClient.getObject(hweiOBSConfig.getBucketName(), objectKey);
			// 读取对象内容
			System.out.println("Object content:");
			InputStream inputStream = obsObject.getObjectContent();
			byte[] b = new byte[1024];
			ServletOutputStream outputStream = response.getOutputStream();
			int len;
			while ((len = inputStream.read(b)) != -1) {
				outputStream.write(b, 0, len);
			}
			System.out.println("getObjectContent successfully");
			outputStream.close();
			inputStream.close();
		} catch (Exception e) {
			System.out.println("getObjectContent failed");
			// 其他异常信息打印
			e.printStackTrace();
		}
	}

}

