package com.cultural.heritage.service.good.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.mapper.AppointmentDateMapper;
import com.cultural.heritage.model.entity.AppointmentDate;
import com.cultural.heritage.model.vo.appointment.AppointmentDateTimePeriodVO;
import com.cultural.heritage.service.good.AppointmentDateService;
import com.cultural.heritage.service.good.GoodService;
import jakarta.annotation.Resource;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class AppointmentDateServiceImpl extends ServiceImpl<AppointmentDateMapper, AppointmentDate> implements AppointmentDateService {


    @Resource
    private GoodService goodService;


    @Resource
    private AppointmentDateMapper appointmentDateMapper;


    /**
     * 校验
     */
    @Override
    public void validAppointmentDate(AppointmentDate appointmentDate, boolean update) {
        Long id = appointmentDate.getId();
        String specificDate = appointmentDate.getSpecificDate();
        Integer isAvailable = appointmentDate.getIsAvailable();
        Long goodId = appointmentDate.getGoodId();
        if (update) {
            if (id == null) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "参数id错误");
            }
        }
        if (ObjectUtils.isEmpty(isAvailable) || isAvailable != 0 && isAvailable != 1) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "是否可预约参数错误");
        }
        if (ObjectUtils.isEmpty(goodId)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "商品id参数为null");
        }
        if (StringUtils.isBlank(specificDate)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "存在参数为空");
        }

    }


    /**
     * (多表联查)查询所有商品的预约情况
     */
    @Override
    public List<AppointmentDateTimePeriodVO> queryAppointmentDateDetail() {
        return appointmentDateMapper.queryAppointmentDateDetail();
    }


    /**
     * (多表联查)根据id查询商品的预约情况
     */
    @Override
    public List<AppointmentDateTimePeriodVO> queryAppointmentDateDetailById(Long goodId) {
        return appointmentDateMapper.queryAppointmentDateDetailById(goodId);
    }


}
